VaultBackend

Struct VaultBackend 

pub struct VaultBackend { /* private fields */ }

Implementations

Source

impl VaultBackend

pub fn new( addr: impl Into<String>, token: impl Into<String>, mount: impl Into<String>, ) -> Result<Self, BackendError>

Build a backend talking to the vault at addr with token, using the transit engine mounted at mount.