Authenticated authorization actor resolution.
Structs
- Authenticated
Actor - A resolved actor that the
PDPcan authorize. - Presenter
Info - Information about the process or bridge that presented the request.
- Proof
Summary - Evidence that established an
AuthenticatedActor. - Transport
Info - Transport facts for the request carrying the actor proof.
Enums
- Proof
Kind - Supported first-cut proof kinds.
- Subject
Resolution Error - Why actor resolution failed.
- Transport
Kind - Supported transport classes.
Functions
- resolve_
local_ actor - Resolve a local request actor from captured peer information.
- resolve_
unauthenticated_ actor - Resolve the configured unauthenticated actor, if enabled.
- resolve_
unix_ actor - Resolve a Unix actor by uid with optional presenter context.